#
# spec file for package tvheadend
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define htsgroup video
%define htsuser hts
%define homedir %{_localstatedir}/lib/tvheadend
Name:           tvheadend
Version:        4.2.2
Release:        1.2
Summary:        A TV Streaming Server
# parsers are from FFMpeg project under LGPL-2.1
# FFdecsa and extra/capmt_ca.c is GPL-2.0+ which is compatibile with GPL-3.0+
# rest of code seems to be GPL-3.0+
License:        GPL-3.0+ and LGPL-2.1
Group:          Productivity/Multimedia/Other
Url:            https://tvheadend.org/
Source0:        https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source2:        %{name}-rpmlintrc
Source3:        %{name}_super
# PATCH-FIX-OPENSUSE tvheadend-fix-service-dependency.patch -- do not wait for or require syslog
Patch2:         %{name}-fix-service-dependency.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(liburiparser)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1320
Requires(pre):  group(%{htsgroup})
%endif
%{?systemd_requires}

%description
A TV streaming server supporting DVB-S, DVB-S2, DVB-C, DVB-T, ATSC, IPTV,
and Analog video (V4L) as input sources.

It also comes with a web interface both used for configuration and
day-to-day operations, such as searching the electronic program guide
(EPG) and for scheduling recordings.

%prep
%setup -q
%patch2 -p1

sed -e "s/-u \([^ ]*\) -g \([^ ]*\)/-u %{htsuser} -g %{htsgroup}/" -i rpm/%{name}.sysconfig
sed -e '/^TVH_ARGS/cTVH_ARGS="-C"' -i debian/%{name}.default
sed -e '/cmake/d' -i configure
echo %{version} > rpm/version

%build
export CFLAGS_NO_WERROR="yes"
%configure \
  --disable-dvbscan \
  --disable-ffmpeg_static \
  --disable-hdhomerun_static
make V=1 %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates/
mkdir -p %{buildroot}%{_sbindir}
install -D -m 644 rpm/%{name}.service %{buildroot}/%{_unitdir}/%{name}.service
sed -i 's@/home/tvheadend@%{homedir}@' rpm/%{name}.sysconfig
install -m 644 rpm/%{name}.sysconfig %{buildroot}/%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
# Install superuser helper script
sed -i 's@/home/tvheadend@%{homedir}@' %{SOURCE3}
install -Dm0755 %{SOURCE3} %{buildroot}%{_sbindir}/%{name}_super
%fdupes -s %{buildroot}%{_datadir}
chmod -x %{buildroot}%{_mandir}/man1/tvheadend.1

%post
%fillup_only %{name}
%service_add_post %{name}.service
cat << 'EOM'
  ==> IMPORTANT: Post configuration tasks;
  ==> 1. Start the tvheadend service (to create home directory).
  ==> 2. Run tvheadend_super to set default username and password.
  ==> 3. Restart tvheadend service.
  ==>
  ==>
  ==> All further configuration is maintained through the web interface:
  ==>
  ==> http://localhost:9981/
  ==>
EOM

%pre
%service_add_pre %{name}.service
getent passwd %htsuser >/dev/null || %{_sbindir}/useradd -g %{htsgroup} -m -d %{homedir} -r -s /bin/false %{htsuser} -c "Tvheadend TV server"

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%doc CONTRIBUTING.md LICENSE.md
%{_bindir}/tvheadend
%{_datadir}/tvheadend
%{_mandir}/man1/tvheadend.1%{?ext_man}
%{_unitdir}/%{name}.service
%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
%{_sbindir}/%{name}_super
%{_sbindir}/rc%{name}

%changelog
* Thu May 18 2017 jengelh@inai.de
- Trim empty phrases from description.
* Wed May 17 2017 aloisio@gmx.com
- Fixed source URL
* Tue May 16 2017 aloisio@gmx.com
- Fixed %%pre
* Tue May 16 2017 aloisio@gmx.com
- Update to version 4.2.2. For a changelog see
  https://github.com/tvheadend/tvheadend/compare/v4.2.1...v4.2.2
* Fri Apr 21 2017 mpluskal@suse.com
- Small spec file adjustments
* Fri Apr 21 2017 aloisio@gmx.com
- Update to version 4.2.1. For a changelog see
  https://github.com/tvheadend/tvheadend/compare/v4.0.10...v4.2.1
- Replaced tvheadend-4.0_no-werror.patch with a variable
  declaration
- Dropped tvheadend-4.0.9-ffmpeg_3.0.patch (merged upstream)
* Mon Apr 10 2017 aloisio@gmx.com
- Update to version 4.0.10. For a changelog see
  https://github.com/tvheadend/tvheadend/compare/v4.0.9...v4.0.10
- Dropped tvheadend-fix-misleading-indent.patch (merged upstream)
* Thu Mar 16 2017 sleep_walker@opensuse.org
- rename tvheadend.rpmlintrc to tvheadend-rpmlintrc to follow
  openSUSE:Factory usus
* Mon Mar 13 2017 sleep_walker@opensuse.org
- require existence of group(%%{htsgroup})
  (which evals to 'group(video)' now)
* Thu Mar  2 2017 sleep_walker@opensuse.org
- remove explicit ffmpeg version requirements
- add tvheadend-4.0.9-ffmpeg_3.0.patch - fix support for ffmpeg 3.0
* Tue Feb 28 2017 sleep_walker@opensuse.org
- rename tvheadend-fix-daemon-user-group.patch to
  tvheadend-fix-service-dependency.patch and use it again - don't
  wait for syslog (user/group part is done by sed)
* Mon Feb 27 2017 sleep_walker@opensuse.org
- change the license of the package to reflect source code files
* Tue Feb 14 2017 sleep_walker@opensuse.org
- replace original (but long-time broken) package with the working one
  living in PackMan build service (and adopt their changelog)
- keep tvheadend-fix-daemon-user-group.patch
- remove pre-systemd stuff and init scripts
- move "homedir" of the user to /var/lib/tvheadend
* Mon Sep 26 2016 malcolmlewis@opensuse.org
- Add tvheadend-fix-misleading-indent.patch: Fix warning/error
  produced with gcc-6.
* Sat Apr  9 2016 malcolmlewis@opensuse.org
- Update to version 4.0.9:
  + https://github.com/tvheadend/tvheadend/compare/v4.0.8...v4.0.9.
- Disable hdhomerun client and static build.
* Sun Feb  7 2016 malcolmlewis@opensuse.org
- Update to version 4.0.8:
  + Changelog on
    https://github.com/tvheadend/tvheadend/compare/v4.0.7...v4.0.8.
- Fix incorrect sed command in spec file to add user hts and video
  group to /etc/sysconfig/tvheadend file.
- Add %%%%doc files.
- Delete source file not bzipped from rpmlintrc file.
- Add helper script to add/update superuser file.
- Update post install message to include post install steps.
* Tue Oct 27 2015 malcolmlewis@opensuse.org
- Update to version 4.0.7:
  + Changelog on
    https://tvheadend.org/projects/tvheadend/wiki/Tvheadend-40.
* Fri Jun 26 2015 aloisio@gmx.com
- Update to version 4.0.5
  * changelog on https://tvheadend.org/projects/tvheadend/wiki/Tvheadend-40
- Added init support for 11.4/SLE_11
- spec cleanup
* Sat Jun  8 2013 p.drouand@gmail.com
- Update to version 3.4
- Clean and rebase specfile
- Add systemd service file to start automatically tvheadend daemon
  and add tvheadend to video group to get it usable by user
- Remove dvb-scan tables archive and pass --disable-dvbscan;
  It doesn't work correctly and is actually obsolete
- Remove tvheadend-3.2.18-dvbscan_data.patch; it's not needed anymore
- Fix executable manpage
* Sat Feb  2 2013 hvogel@opensuse.org
- Update to version 3.2.18
* Tue Mar 27 2012 hvogel@opensuse.org
- Don't build with Werror
- Add summary/description
* Fri Apr 22 2011 hvogel@opensuse.org
- Initial package, version 2.12
